@@ -708,7 +708,7 @@ fill_combo_model (PlumaFileBrowserWidget * obj)
 	GtkTreeIter iter;
 	GdkPixbuf *icon;
 
-	icon = pluma_file_browser_utils_pixbuf_from_theme (GTK_STOCK_HOME, GTK_ICON_SIZE_MENU);
+	icon = pluma_file_browser_utils_pixbuf_from_theme ("go-home", GTK_ICON_SIZE_MENU);
 
 	gtk_tree_store_append (store, &iter, NULL);
 	gtk_tree_store_set (store, &iter,
@@ -2473,7 +2473,11 @@ directory_open (PlumaFileBrowserWidget *obj,
 	if (FILE_IS_DIR (flags)) {
 		result = TRUE;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+		if (!gtk_show_uri_on_window (NULL, uri, GDK_CURRENT_TIME, &error)) {
+#else
 		if (!gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (obj)), uri, GDK_CURRENT_TIME, &error)) {
+#endif
 			g_signal_emit (obj, signals[ERROR], 0,
 				       PLUMA_FILE_BROWSER_ERROR_OPEN_DIRECTORY,
 				       error->message);
