@@ -36,6 +36,7 @@
 #include <unistd.h>
 
 #include <glib/gi18n.h>
+#include <gdk/gdkx.h>
 
 #include "pluma-app.h"
 #include "pluma-prefs-manager-app.h"
@@ -350,7 +351,7 @@ app_weak_notify (gpointer data,
  * Returns the #PlumaApp object. This object is a singleton and
  * represents the running pluma instance.
  *
- * Return value: the #PlumaApp pointer
+ * Return value: (transfer none): the #PlumaApp pointer
  */
 PlumaApp *
 pluma_app_get_default (void)
@@ -555,7 +556,7 @@ pluma_app_create_window_real (PlumaApp    *app,
  *
  * Create a new #PlumaWindow part of @app.
  *
- * Return value: the new #PlumaWindow
+ * Return value: (transfer none): the new #PlumaWindow
  */
 PlumaWindow *
 pluma_app_create_window (PlumaApp  *app,
@@ -592,7 +593,7 @@ _pluma_app_restore_window (PlumaApp    *app,
  *
  * Returns all the windows currently present in #PlumaApp.
  *
- * Return value: (transfer none): the list of #PlumaWindows objects.
+ * Return value: (element-type Pluma.Window) (transfer none): the list of #PlumaWindows objects.
  * The list should not be freed
  */
 const GList *
@@ -609,7 +610,7 @@ pluma_app_get_windows (PlumaApp *app)
  *
  * Retrives the #PlumaWindow currently active.
  *
- * Return value: the active #PlumaWindow
+ * Return value: (transfer none): the active #PlumaWindow
  */
 PlumaWindow *
 pluma_app_get_active_window (PlumaApp *app)
@@ -649,12 +650,12 @@ is_in_viewport (PlumaWindow  *window,
 	/* Check for screen and display match */
 	display = gdk_screen_get_display (screen);
 	cur_name = gdk_display_get_name (display);
-	cur_n = gdk_screen_get_number (screen);
+	cur_n = gdk_x11_screen_get_screen_number (screen);
 
 	s = gtk_window_get_screen (GTK_WINDOW (window));
 	display = gdk_screen_get_display (s);
 	name = gdk_display_get_name (display);
-	n = gdk_screen_get_number (s);
+	n = gdk_x11_screen_get_screen_number (s);
 
 	if (strcmp (cur_name, name) != 0 || cur_n != n)
 		return FALSE;
@@ -675,8 +676,8 @@ is_in_viewport (PlumaWindow  *window,
 	x += vp_x;
 	y += vp_y;
 
-	sc_width = gdk_screen_get_width (screen);
-	sc_height = gdk_screen_get_height (screen);
+	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+				 &sc_width, &sc_height);
 
 	return x + width * .25 >= viewport_x &&
 	       x + width * .75 <= viewport_x + sc_width &&
