@@ -275,24 +275,6 @@ set_gtk_image_from_gtk_image (GtkImage *image,
 			gtk_image_set_from_pixbuf (image, pb);
 		}
 		break;
-	case GTK_IMAGE_STOCK:
-		{
-			gchar *s_id;
-			GtkIconSize s;
-
-			gtk_image_get_stock (source, &s_id, &s);
-			gtk_image_set_from_stock (image, s_id, s);
-		}
-		break;
-	case GTK_IMAGE_ICON_SET:
-		{
-			GtkIconSet *is;
-			GtkIconSize s;
-
-			gtk_image_get_icon_set (source, &is, &s);
-			gtk_image_set_from_icon_set (image, is, s);
-		}
-		break;
 	case GTK_IMAGE_ANIMATION:
 		{
 			GdkPixbufAnimation *a;
@@ -311,9 +293,9 @@ set_gtk_image_from_gtk_image (GtkImage *image,
 		}
 		break;
 	default:
-		gtk_image_set_from_stock (image,
-					  GTK_STOCK_FILE,
-					  GTK_ICON_SIZE_MENU);
+		gtk_image_set_from_icon_name (image,
+		                              "text-x-generic",
+		                              GTK_ICON_SIZE_MENU);
 	}
 }
 
@@ -337,9 +319,9 @@ sync_title (PlumaPanel     *panel,
 		gtk_label_set_text (GTK_LABEL (panel->priv->title_label), 
 				    _("Empty"));
 
-		gtk_image_set_from_stock (GTK_IMAGE (panel->priv->title_image),
-					  GTK_STOCK_FILE,
-					  GTK_ICON_SIZE_MENU);
+		gtk_image_set_from_icon_name (GTK_IMAGE (panel->priv->title_image),
+		                              "text-x-generic",
+		                              GTK_ICON_SIZE_MENU);
 	}
 }
 
@@ -494,8 +476,8 @@ build_vertical_panel (PlumaPanel *panel)
 			    0);
 		
 	panel->priv->title_image = 
-				gtk_image_new_from_stock (GTK_STOCK_FILE,
-							  GTK_ICON_SIZE_MENU);
+				gtk_image_new_from_icon_name ("text-x-generic",
+				                              GTK_ICON_SIZE_MENU);
 	gtk_box_pack_start (GTK_BOX (icon_name_hbox), 
 			    panel->priv->title_image, 
 			    FALSE, 
@@ -669,8 +651,8 @@ pluma_panel_add_item (PlumaPanel  *panel,
 	if (image == NULL)
 	{
 		/* default to empty */
-		data->icon = gtk_image_new_from_stock (GTK_STOCK_FILE,
-						       GTK_ICON_SIZE_MENU);
+		data->icon = gtk_image_new_from_icon_name ("text-x-generic",
+		                                           GTK_ICON_SIZE_MENU);
 	}
 	else
 	{
@@ -717,14 +699,14 @@ void
 pluma_panel_add_item_with_stock_icon (PlumaPanel  *panel, 
 				      GtkWidget   *item, 
 				      const gchar *name,
-				      const gchar *stock_id)
+				      const gchar *icon_name)
 {
 	GtkWidget *icon = NULL;
 
-	if (stock_id != NULL)
+	if (icon_name != NULL)
 	{
-		icon = gtk_image_new_from_stock (stock_id,
-						 GTK_ICON_SIZE_MENU);
+		icon = gtk_image_new_from_icon_name (icon_name,
+		                                     GTK_ICON_SIZE_MENU);
 	}
 
 	pluma_panel_add_item (panel, item, name, icon);
